@@ -14,7 +14,8 @@ def ssh(challenge, host, network="bridge"):
     path = str(Path(challenge.file_path).parent.absolute())
     if os.path.exists(f"{path}/docker-compose.yml"):
         log.info("Deploying docker-compose")
-        subprocess.run(["docker-compose", "-f", f"{challenge}/docker-compose.yml", "up", "-d"], check=True)
+        subprocess.run(["docker-compose", "-f", f"{path}/docker-compose.yml", "down"], check=False)
+        subprocess.run(["docker-compose", "-f", f"{path}/docker-compose.yml", "up", "-d"], check=True)
         log.info("Docker-compose deployed correctly.")
         return None
 
@@ -22,6 +23,13 @@ def ssh(challenge, host, network="bridge"):
         client = from_env(use_ssh_client=True)
 
         image_name = sanitize_name(challenge.get("image"))
+        if image_name == "":
+            image_name = sanitize_name(challenge.get("name"))
+            if image_name == "":
+                log.warning("Unable to build docker image for " + challenge.get("name"))
+                return None
+
+
         container_name = image_name + "_cont"
 
         image, _ = client.images.build(path=path, tag=image_name)
